==> haskell-s-cargot-0.1.5.0-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-s-cargot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 s-cargot
version:              0.1.5.0
visibility:           public
id:                   s-cargot-0.1.5.0-8TmHlnZydd6CKFgRG4a3z3
key:                  s-cargot-0.1.5.0-8TmHlnZydd6CKFgRG4a3z3
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <s-cargot@infinitenegativeutility.com>
author:               Getty Ritter <s-cargot@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/s-cargot
synopsis:             A flexible, extensible s-expression library.
description:
    S-Cargot is a library for working with s-expressions in
    a modular and extensible way, opting for genericity and
    flexibility instead of speed. Instead of understanding
    one particular form of s-expression, the S-Cargot library
    exposes tools for parsing or emitting different kinds of
    s-expressions, including features not normally included
    in an s-expression library like reader macros or tight
    control over indentation in pretty-printing.

category:             Data
abi:                  772aa9f89f2117eafcc3915f05eea853
exposed:              True
exposed-modules:
    Data.SCargot Data.SCargot.Atom Data.SCargot.Comments
    Data.SCargot.Common Data.SCargot.Language.Basic
    Data.SCargot.Language.HaskLike Data.SCargot.Parse
    Data.SCargot.Print Data.SCargot.Repr Data.SCargot.Repr.Basic
    Data.SCargot.Repr.Rich Data.SCargot.Repr.WellFormed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-s-cargot
hs-libraries:         HSs-cargot-0.1.5.0-8TmHlnZydd6CKFgRG4a3z3
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-s-cargot/html/s-cargot.haddock
haddock-html:         /usr/share/doc/haskell-s-cargot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-s-cargot-0.1.6.0-29.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-s-cargot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 s-cargot
version:              0.1.6.0
visibility:           public
id:                   s-cargot-0.1.6.0-EBS66Erwl1yG4w8i3HDHTg
key:                  s-cargot-0.1.6.0-EBS66Erwl1yG4w8i3HDHTg
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <s-cargot@infinitenegativeutility.com>
author:               Getty Ritter <s-cargot@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/s-cargot
synopsis:             A flexible, extensible s-expression library.
description:
    S-Cargot is a library for working with s-expressions in
    a modular and extensible way, opting for genericity and
    flexibility instead of speed. Instead of understanding
    one particular form of s-expression, the S-Cargot library
    exposes tools for parsing or emitting different kinds of
    s-expressions, including features not normally included
    in an s-expression library like reader macros or tight
    control over indentation in pretty-printing.

category:             Data
abi:                  ad11ec5f83e4fbb22057bcdc13a00211
exposed:              True
exposed-modules:
    Data.SCargot Data.SCargot.Atom Data.SCargot.Comments
    Data.SCargot.Common Data.SCargot.Language.Basic
    Data.SCargot.Language.HaskLike Data.SCargot.Parse
    Data.SCargot.Print Data.SCargot.Repr Data.SCargot.Repr.Basic
    Data.SCargot.Repr.Rich Data.SCargot.Repr.WellFormed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/s-cargot-0.1.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/s-cargot-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/s-cargot-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-s-cargot
hs-libraries:         HSs-cargot-0.1.6.0-EBS66Erwl1yG4w8i3HDHTg
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-s-cargot/html/s-cargot.haddock
haddock-html:         /usr/share/doc/haskell-s-cargot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
